@@ -1,8 +1,9 @@
+from graphql.execution.base import ResolveInfo
+
 from dagster import check
 from dagster.core.definitions.run_request import InstigatorType
 from dagster.core.host_representation import PipelineSelector, RepositorySelector, ScheduleSelector
 from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
-from graphql.execution.base import ResolveInfo
 
 from .utils import UserFacingGraphQLError, capture_error
 
@@ -71,6 +72,7 @@ def get_schedules_or_error(graphene_info, repository_selector):
         state.name: state
         for state in graphene_info.context.instance.all_instigator_state(
             repository_origin_id=repository.get_external_origin_id(),
+            repository_selector_id=repository_selector.selector_id,
             instigator_type=InstigatorType.SCHEDULE,
         )
     }
@@ -102,7 +104,8 @@ def get_schedules_for_pipeline(graphene_info, pipeline_selector):
             continue
 
         schedule_state = graphene_info.context.instance.get_instigator_state(
-            external_schedule.get_external_origin_id()
+            external_schedule.get_external_origin_id(),
+            external_schedule.selector_id,
         )
         results.append(GrapheneSchedule(external_schedule, schedule_state))
 
@@ -126,7 +129,7 @@ def get_schedule_or_error(graphene_info, schedule_selector):
         )
 
     schedule_state = graphene_info.context.instance.get_instigator_state(
-        external_schedule.get_external_origin_id()
+        external_schedule.get_external_origin_id(), external_schedule.selector_id
     )
     return GrapheneSchedule(external_schedule, schedule_state)
 
