@@ -1,9 +1,4 @@
 import graphene
-from dagster import check
-from dagster.core.host_representation import ExternalPartitionSet, RepositoryHandle
-from dagster.core.storage.pipeline_run import PipelineRunsFilter
-from dagster.core.storage.tags import PARTITION_NAME_TAG, PARTITION_SET_TAG
-from dagster.utils import merge_dicts
 from dagster_graphql.implementation.fetch_partition_sets import (
     get_partition_by_name,
     get_partition_config,
@@ -13,14 +8,21 @@ from dagster_graphql.implementation.fetch_partition_sets import (
 )
 from dagster_graphql.implementation.fetch_runs import get_runs
 
+from dagster import check
+from dagster.core.host_representation import ExternalPartitionSet, RepositoryHandle
+from dagster.core.storage.pipeline_run import RunsFilter
+from dagster.core.storage.tags import PARTITION_NAME_TAG, PARTITION_SET_TAG
+from dagster.utils import merge_dicts
+
 from .errors import (
     GraphenePartitionSetNotFoundError,
     GraphenePipelineNotFoundError,
     GraphenePythonError,
 )
-from .inputs import GraphenePipelineRunsFilter
-from .pipelines.pipeline import GraphenePipelineRun
-from .pipelines.status import GraphenePipelineRunStatus
+from .inputs import GrapheneRunsFilter
+from .pipelines.pipeline import GrapheneRun
+from .pipelines.status import GrapheneRunStatus
+from .repository_origin import GrapheneRepositoryOrigin
 from .tags import GraphenePipelineTag
 from .util import non_null_list
 
@@ -48,7 +50,7 @@ class GraphenePartitionRunConfigOrError(graphene.Union):
 class GraphenePartitionStatus(graphene.ObjectType):
     id = graphene.NonNull(graphene.String)
     partitionName = graphene.NonNull(graphene.String)
-    runStatus = graphene.Field(GraphenePipelineRunStatus)
+    runStatus = graphene.Field(GrapheneRunStatus)
 
     class Meta:
         name = "PartitionStatus"
@@ -81,12 +83,12 @@ class GraphenePartition(graphene.ObjectType):
     runConfigOrError = graphene.NonNull(GraphenePartitionRunConfigOrError)
     tagsOrError = graphene.NonNull(GraphenePartitionTagsOrError)
     runs = graphene.Field(
-        non_null_list(GraphenePipelineRun),
-        filter=graphene.Argument(GraphenePipelineRunsFilter),
+        non_null_list(GrapheneRun),
+        filter=graphene.Argument(GrapheneRunsFilter),
         cursor=graphene.String(),
         limit=graphene.Int(),
     )
-    status = graphene.Field(GraphenePipelineRunStatus)
+    status = graphene.Field(GrapheneRunStatus)
 
     class Meta:
         name = "Partition"
@@ -131,14 +133,14 @@ class GraphenePartition(graphene.ObjectType):
         }
         if filters is not None:
             filters = filters.to_selector()
-            runs_filter = PipelineRunsFilter(
+            runs_filter = RunsFilter(
                 run_ids=filters.run_ids,
-                pipeline_name=filters.pipeline_name,
+                pipeline_name=filters.job_name,
                 statuses=filters.statuses,
                 tags=merge_dicts(filters.tags, partition_tags),
             )
         else:
-            runs_filter = PipelineRunsFilter(tags=partition_tags)
+            runs_filter = RunsFilter(tags=partition_tags)
 
         return get_runs(
             graphene_info, runs_filter, cursor=kwargs.get("cursor"), limit=kwargs.get("limit")
@@ -172,6 +174,7 @@ class GraphenePartitionSet(graphene.ObjectType):
     )
     partition = graphene.Field(GraphenePartition, partition_name=graphene.NonNull(graphene.String))
     partitionStatusesOrError = graphene.NonNull(GraphenePartitionStatusesOrError)
+    repositoryOrigin = graphene.NonNull(GrapheneRepositoryOrigin)
 
     class Meta:
         name = "PartitionSet"
@@ -217,6 +220,10 @@ class GraphenePartitionSet(graphene.ObjectType):
             graphene_info, self._external_repository_handle, self._external_partition_set.name
         )
 
+    def resolve_repositoryOrigin(self, _):
+        origin = self._external_partition_set.get_external_origin().external_repository_origin
+        return GrapheneRepositoryOrigin(origin)
+
 
 class GraphenePartitionSetOrError(graphene.Union):
     class Meta:
