@@ -4,7 +4,7 @@ from dagster import check
 from dagster.core.definitions.events import AssetKey
 from dagster.core.execution.backfill import BulkActionStatus
 from dagster.core.host_representation import (
-    InstigationSelector,
+    InstigatorSelector,
     RepositorySelector,
     ScheduleSelector,
     SensorSelector,
@@ -50,6 +50,7 @@ from ..backfill import (
 )
 from ..external import (
     GrapheneRepositoriesOrError,
+    GrapheneRepositoryConnection,
     GrapheneRepositoryOrError,
     GrapheneWorkspaceOrError,
 )
@@ -98,7 +99,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
     version = graphene.NonNull(graphene.String)
 
-    repositoriesOrError = graphene.NonNull(GrapheneRepositoriesOrError)
+    repositoriesOrError = graphene.Field(
+        graphene.NonNull(GrapheneRepositoriesOrError),
+        repositorySelector=graphene.Argument(GrapheneRepositorySelector),
+    )
+
     repositoryOrError = graphene.Field(
         graphene.NonNull(GrapheneRepositoryOrError),
         repositorySelector=graphene.NonNull(GrapheneRepositorySelector),
@@ -262,7 +267,16 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
     permissions = graphene.Field(non_null_list(GraphenePermission))
 
-    def resolve_repositoriesOrError(self, graphene_info):
+    def resolve_repositoriesOrError(self, graphene_info, **kwargs):
+        if kwargs.get("repositorySelector"):
+            return GrapheneRepositoryConnection(
+                nodes=[
+                    fetch_repository(
+                        graphene_info,
+                        RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
+                    )
+                ]
+            )
         return fetch_repositories(graphene_info)
 
     def resolve_repositoryOrError(self, graphene_info, **kwargs):
@@ -326,7 +340,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
 
     def resolve_instigationStateOrError(self, graphene_info, instigationSelector):
         return get_instigator_state_or_error(
-            graphene_info, InstigationSelector.from_graphql_input(instigationSelector)
+            graphene_info, InstigatorSelector.from_graphql_input(instigationSelector)
         )
 
     def resolve_unloadableInstigationStatesOrError(self, graphene_info, **kwargs):
@@ -461,7 +475,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
             GrapheneAssetNode(
                 node.repository_location,
                 node.external_repository,
-                node.get_external_asset_node(),
+                node.external_asset_node,
                 materialization_loader=materialization_loader,
             )
             for node in results
