@@ -1,4 +1,5 @@
 import graphene
+
 from dagster import check
 from dagster.core.host_representation import RepresentedPipeline
 
@@ -6,7 +7,7 @@ from ..implementation.run_config_schema import resolve_is_run_config_valid
 from .config_types import GrapheneConfigType, to_config_type
 from .errors import GrapheneModeNotFoundError, GraphenePipelineNotFoundError, GraphenePythonError
 from .pipelines.config_result import GraphenePipelineConfigValidationResult
-from .runs import GrapheneRunConfigData
+from .runs import GrapheneRunConfigData, parse_run_config_input
 from .util import non_null_list
 
 
@@ -74,7 +75,7 @@ class GrapheneRunConfigSchema(graphene.ObjectType):
             graphene_info,
             self._represented_pipeline,
             self._mode,
-            kwargs.get("runConfigData", {}),
+            parse_run_config_input(kwargs.get("runConfigData", {})),
         )
 
 
