@@ -1,31 +1,28 @@
 import graphene
+
 from dagster import check
 from dagster.core.host_representation import ExternalSchedule, ScheduleSelector
 from dagster.core.host_representation.selector import RepositorySelector
-from dagster.core.scheduler.job import JobTickStatsSnapshot
+from dagster.core.workspace.permissions import Permissions
 
-from ...implementation.fetch_schedules import (
-    reconcile_scheduler_state,
-    start_schedule,
-    stop_schedule,
-)
-from ...implementation.utils import capture_error, check_read_only
+from ...implementation.fetch_schedules import start_schedule, stop_schedule
+from ...implementation.utils import capture_error, check_permission
 from ..errors import (
     GraphenePythonError,
-    GrapheneReadOnlyError,
     GrapheneRepositoryNotFoundError,
     GrapheneScheduleNotFoundError,
     GrapheneSchedulerNotDefinedError,
+    GrapheneUnauthorizedError,
 )
 from ..inputs import GrapheneRepositorySelector, GrapheneScheduleSelector
-from ..jobs import GrapheneJobState
+from ..instigation import GrapheneInstigationState
 from .schedules import (
     GrapheneSchedule,
     GrapheneScheduleOrError,
     GrapheneSchedules,
     GrapheneSchedulesOrError,
 )
-from .ticks import GrapheneJobTickStatus
+from .ticks import GrapheneInstigationTickStatus
 
 
 class GrapheneScheduleStatus(graphene.Enum):
@@ -50,57 +47,8 @@ class GrapheneSchedulerOrError(graphene.Union):
         name = "SchedulerOrError"
 
 
-class GrapheneScheduleTickStatsSnapshot(graphene.ObjectType):
-    ticks_started = graphene.NonNull(graphene.Int)
-    ticks_succeeded = graphene.NonNull(graphene.Int)
-    ticks_skipped = graphene.NonNull(graphene.Int)
-    ticks_failed = graphene.NonNull(graphene.Int)
-
-    class Meta:
-        name = "ScheduleTickStatsSnapshot"
-
-    def __init__(self, stats):
-        super().__init__(
-            ticks_started=stats.ticks_started,
-            ticks_succeeded=stats.ticks_succeeded,
-            ticks_skipped=stats.ticks_skipped,
-            ticks_failed=stats.ticks_failed,
-        )
-        self._stats = check.inst_param(stats, "stats", JobTickStatsSnapshot)
-
-
-class GrapheneReconcileSchedulerStateSuccess(graphene.ObjectType):
-    message = graphene.NonNull(graphene.String)
-
-    class Meta:
-        name = "ReconcileSchedulerStateSuccess"
-
-
-class GrapheneReconcileSchedulerStateMutationResult(graphene.Union):
-    class Meta:
-        types = (GrapheneReadOnlyError, GraphenePythonError, GrapheneReconcileSchedulerStateSuccess)
-        name = "ReconcileSchedulerStateMutationResult"
-
-
-class GrapheneReconcileSchedulerStateMutation(graphene.Mutation):
-    Output = graphene.NonNull(GrapheneReconcileSchedulerStateMutationResult)
-
-    class Arguments:
-        repository_selector = graphene.NonNull(GrapheneRepositorySelector)
-
-    class Meta:
-        name = "ReconcileSchedulerStateMutation"
-
-    @capture_error
-    @check_read_only
-    def mutate(self, graphene_info, repository_selector):
-        return reconcile_scheduler_state(
-            graphene_info, RepositorySelector.from_graphql_input(repository_selector)
-        )
-
-
 class GrapheneScheduleStateResult(graphene.ObjectType):
-    scheduleState = graphene.NonNull(GrapheneJobState)
+    scheduleState = graphene.NonNull(GrapheneInstigationState)
 
     class Meta:
         name = "ScheduleStateResult"
@@ -108,7 +56,7 @@ class GrapheneScheduleStateResult(graphene.ObjectType):
 
 class GrapheneScheduleMutationResult(graphene.Union):
     class Meta:
-        types = (GraphenePythonError, GrapheneScheduleStateResult)
+        types = (GraphenePythonError, GrapheneUnauthorizedError, GrapheneScheduleStateResult)
         name = "ScheduleMutationResult"
 
 
@@ -121,6 +69,8 @@ class GrapheneStartScheduleMutation(graphene.Mutation):
     class Meta:
         name = "StartScheduleMutation"
 
+    @capture_error
+    @check_permission(Permissions.START_SCHEDULE)
     def mutate(self, graphene_info, schedule_selector):
         return start_schedule(graphene_info, ScheduleSelector.from_graphql_input(schedule_selector))
 
@@ -134,6 +84,8 @@ class GrapheneStopRunningScheduleMutation(graphene.Mutation):
     class Meta:
         name = "StopRunningScheduleMutation"
 
+    @capture_error
+    @check_permission(Permissions.STOP_RUNNING_SCHEDULE)
     def mutate(self, graphene_info, schedule_origin_id):
         return stop_schedule(graphene_info, schedule_origin_id)
 
@@ -148,10 +100,7 @@ def types():
 
     # Double check mutations don't appear twice
     return [
-        GrapheneJobTickStatus,
-        GrapheneReconcileSchedulerStateMutation,
-        GrapheneReconcileSchedulerStateMutationResult,
-        GrapheneReconcileSchedulerStateSuccess,
+        GrapheneInstigationTickStatus,
         GrapheneSchedule,
         GrapheneScheduleMutationResult,
         GrapheneScheduleOrError,
@@ -164,7 +113,6 @@ def types():
         GrapheneScheduleTick,
         GrapheneScheduleTickFailureData,
         GrapheneScheduleTickSpecificData,
-        GrapheneScheduleTickStatsSnapshot,
         GrapheneScheduleTickSuccessData,
         GrapheneStartScheduleMutation,
         GrapheneStopRunningScheduleMutation,
